@@ -19,6 +19,7 @@ class Configuration:
         module_rule: str = "default",
         recording_enabled: bool = False,
         timeout: int = 5,
+        audio_input_delay: int = 0,
     ):
         self.input_type = input_type
         self.default_voice = default_voice
@@ -29,6 +30,7 @@ class Configuration:
         self.module_rule = module_rule
         self.recording_enabled = recording_enabled
         self.timeout = timeout
+        self.audio_input_delay = audio_input_delay
 
         if isinstance(llm_provider, str):
             self.llm_provider = LLMProvider(llm_provider)
@@ -50,4 +52,5 @@ class Configuration:
             "module_rule": self.module_rule,
             "recording_enabled": self.recording_enabled,
             "timeout": self.timeout,
+            "audio_input_delay": self.audio_input_delay,
         }
